#!/bin/sh

#
#    STEP 1: Find the rRNA locations on the genomes
#
#    script: Apply FeatureExtract to extract all nonrrna sequences 
#            from the NCBI bacterial genomes genbank files
#            file source ftp://ftp.ncbi.nlm.nih.gov/genomes/Bacteria/all.gbk.tar.gz
#            FeatureExtract source http://www.cbs.dtu.dk/services/FeatureExtract/
#
#    contact: evguenia.kopylova@lifl.fr
#
#    date   : March 2012
#

# path to all.gbk (NCBI bacterial genomes) folder
XSTK="all.gbk"

# path to FeatureExtract 1.2 gb2tab.py module
EXTRACTOR="gb2tab.py"

# path to output folder of rRNA sequences found per genome
OUT="all.rrna.fna"


# for each bacterial genome folder (ex. Acaryochloris_marina_MBIC11017_uid58167)
for folder in $XSTK/*
do
	folderonly=$(basename $folder)
	mkdir $OUT/$folderonly

	# for each complete sequence in the folder (ex. NC_009925.gbk)
	for file in $folder/*.gbk
	do

#       uncomment 2 lines below if you would like to monitor which folders have been processed		
#		echo "$file"
#		echo "$folderonly"
		 
		# extract the rRNAs from the genbank file
        # we only keep the tag information which gives the locations of the rRNA sequence
        # on the complete sequence, and the rRNA sequence itself
		python $EXTRACTOR -f 'rRNA' -q --entryname $file | awk '{printf ">"; print $1; print $2}' > $OUT/$folderonly/$(basename $(basename $file) .gbk).fna
	done
done

